/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.TagSupport;


/**
 * <p>
 * This is an abstract implementation of the NodeDiscovery interface and is useful to NodeDiscovery
 *  implementations that are also a
 * Tag.  This abstract class simplifies the work required when an implementation of the
 *  NodeDiscovery will also provide services as
 * a tag and provides an attribute to set the title.  This abstract class will implement
 *  doStartTag, call getCurrentNode to get the current node
 * and then set the result as a page scope attribute using
 *  BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE.
 * </p>
 * <p>Thread Safety:< This class is thread safe in the context of the JSP rendering process</p>
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public abstract class AbstractNodeDiscovery extends TagSupport implements NodeDiscovery {
    /**
     * <p>Represents the title associated with this node.  This variable is set initially to null,
     *  is mutable and can be null but never an empty
     * string.  A null title means that the title for the current node should default that that
     *  found in the PathDiscovery data source.
     * This variable is referenced by the associated getter/setter methods</p>
     */
    private String title = null;

    /**
     * <p>Constructs this abstract base.</p>
     */
    protected AbstractNodeDiscovery() {
    }

    /**
     * <p>This method will get the current node url and if found, save it to
     *  BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE attribute
     * using page scope.</p>
     *
     *
     * @return Always SKIP_BODY
     * @throws JspException if an exception occurred (none should however)
     */
    public int doStartTag() throws JspException {
        BreadCrumbNode node = getCurrentNode(this.pageContext);

        if (node != null) {
            pageContext.setAttribute(BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE, node, PageContext.PAGE_SCOPE);
        }

        return SKIP_BODY;
    }

    /**
     * <p>Returns value of title property.</p>
     *
     *
     * @return The possibly null, non-empty string representing the title
     */
    public String getTitle() {
        return title;
    }

    /**
     * <p>Sets value of title property.</p>
     *
     *
     * @param title A possibly null, possibly empty (trim'd) string representing the title
     */
    public void setTitle(String title) {
        if (title.trim().length() == 0) {
            this.title = null;
        } else {
            this.title = title;
        }
    }
}
