/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import javax.servlet.jsp.PageContext;


/**
 * <p>
 * This interface defines the contract for classes wishing to discover the current node.
 * Implementations of this interface will be called
 * when the current page has not been defined (ie a page scope attribute for
 * BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE).
 * The implementation should discover, in it's own way, the current node when
 * getCurrentNode() is called and return the node representation
 * of that url.
 * </p>
 * <p>Thread Safety: Implementations should be thread safe in the context of the JSP rendering process</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public interface NodeDiscovery {
    /**
     * <p>Called to retrieve the node representation of the current page. If the current page
     *  could not be found or is not applicable - simply return null. The returned node should
     *  include any query strings available</p>
     * <p>Implementation notes:  Simply the method signature for the interface</p>
     *
     *
     * @return A non-null Node representing the current url or null if the node couldn't be determined
     * @param pageContext A non-null page context to use
     * @throws IllegalArgumentException if the page context is null
     * @throws BreadCrumbException if an exception occurs discovering the page
     */
    public BreadCrumbNode getCurrentNode(PageContext pageContext) throws BreadCrumbException;
}
