/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodediscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.AbstractNodeDiscovery;
import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.PageContext;


/**
 * <p>This tag and implementation of the NodeDiscovery will discover the current node from the
 *  HttpServletRequest. This implementation will return a valid Uri (with query string if specified)
 *  in the getCurrentNode() method. If this is used as a tag, this will define a page variable called
 *  BreadCrumbTrailTag.BREADCRUMB_CURRENT_NODE with the value a string representing the node uri
 *  with query string. </p>
 * <p>Thread Safety: This class is thread safe in the context of the JSP rendering process</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class HttpServletNodeDiscoveryTag extends AbstractNodeDiscovery {
    /**
     * <p>Constructs the HttpServletNodeDiscoveryTag using no constructor parameters.</p>
     */
    public HttpServletNodeDiscoveryTag() {
        super();
    }

    /**
     * <p>Discovers the node url from an HttpServletRequest. If none is found or if the
     *  servletrequest is not of HttpServletRequest type, a null is returned</p>
     *
     *
     * @param pageContext A non-null page context to use
     * @return A null if not applicable or a non-null, non-empty string representing the
     *  contextual uri (with query string)
     * @throws IllegalArgumentException if the pageContext is null
     */
    public BreadCrumbNode getCurrentNode(PageContext pageContext) {
        if (pageContext == null) {
            throw new IllegalArgumentException("pageContext cannot be null.");
        }

        ServletRequest request = pageContext.getRequest();

        if ((request == null) || !(request instanceof HttpServletRequest)) {
            return null;
        }

        HttpServletRequest httpRequest = (HttpServletRequest) request;

        return new BreadCrumbNode(httpRequest.getRequestURI() + "?" + httpRequest.getQueryString(),
            getTitle());
    }
}
