/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodeformatter;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbTrailTag;

import javax.servlet.ServletRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;


/**
 * <p>This tag will format the node and style using a template.  A template is a separate file
 * that will be included in the out stream.  This class will take the current node/style and
 * define them as request attributes when the template file is included (those attributes can
 * then be used by the template file to format the correct representation of them).</p>
 * <p>Thread Safety: This class is thread safe in the context of the JSP rendering process</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class TemplateNodeFormatterTag extends TagSupport {
    /**
     * <p>Represents the template file that will be used when formatting this tag. This
     *  variable is set by the constructor, is mutable and can be null or an empty (trim'd)
     *  string to specify template is to be used (and thus nothing produced by this tag).
     *  Please note that it is expected (but not required) that the value will be a non-null,
     *  non-empty value.  This variable is referenced by the associated getter/setter methods
     *  and the doStartTag methods</p>
     */
    private String template;

    /**
     * <p>Constructs the TemplateNodeFormatterTag using the configuration manager to set the
     * initial value of the template.</p>
     *
     *
     * @param template A possibly null, possibly empty (trim'd) string representing the template
     *  to use
     */
    public TemplateNodeFormatterTag(String template) {
        this.template = template;
    }

    /**
     * This is the getter method for the template variable.
     *
     *
     * @return A possibly null, possibly empty (trim'd) string representing the template to use
     */
    public String getTemplate() {
        return template;
    }

    /**
     * Sets the template that will be used for rendering this tag.
     *
     *
     * @param template A possibly null, possibly empty (trim'd) string representing the template
     *  to use
     */
    public void setTemplate(String template) {
        this.template = template;
    }

    /**
     * <p>This method will take the current node and format, make them into request attributes
     *  and include the template file (which is assumed to use the request attributes).</p>
     *
     *
     * @return Always SKIP_BODY
     * @throws JspException if some exception occurs during processing
     */
    public int doStartTag() throws JspException {
        if ((template == null) || (template.trim().length() == 0)) {
            return SKIP_BODY;
        }

        try {
            // set attribute in request
            ServletRequest request = pageContext.getRequest();
            request.setAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_NODE,
                pageContext.getAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_NODE));
            request.setAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_STYLE_CLASS,
                pageContext.getAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_STYLE_CLASS));

            // include template
            pageContext.include(template);
        } catch (Exception e) {
            throw new JspException("Failed to render JSP.", e);
        }

        return SKIP_BODY;
    }
}
